Crate celerix_core

Crate celerix_core 

Re-exports

pub use sqlx_d1;
pub use axum;
pub use serde;
pub use serde_json;
pub use worker;

Modules

send

Macros

debug
Log a debug message to the Cloudflare Workers console.
error
Log an error message to the Cloudflare Workers console.
info
Log an info message to the Cloudflare Workers console.
json
Construct a serde_json::Value from a JSON literal.
warn
Log a warning message to the Cloudflare Workers console.

Structs

App
The main application builder for Celerix.
Ctx
Context passed to scheduled task handlers.
DB
A celerix database handle backed by Cloudflare D1 via sqlx-d1.
Error
Celerix error type. Wraps worker::Error.
Extension
Extractor and response for extensions.
Json
JSON Extractor / Response.
Queue
A celerix Queue handle.
ScheduleBuilder
Builder returned by app.schedule().
ScheduledTask
A registered scheduled task.
Storage
A celerix Storage handle backed by Cloudflare Workers KV.

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
Job
Trait that every job struct must implement.
JobExt
Extension trait that adds dispatch() to any Job implementor.
QueueHandler
Trait for queue message handlers.
Serialize
A data structure that can be serialized into any data format supported by Serde.
Service
An asynchronous function from a Request to a Response.

Functions

dispatch_job
Dispatch a raw JSON string from a queue message to the right Job handler.
resolve_binding
Resolve a user-facing binding name (e.g. “QUEUE”) to the full prefixed binding (e.g. “EXAMPLE_BASIC_QUEUE”).
should_run
Check if a task should run given the current epoch timestamp (seconds). Called once per minute by the cron trigger.

Type Aliases

QueueMessage
A single message from a Cloudflare Queue.
Result

Derive Macros

Deserialize
Serialize